@@ -11,87 +11,75 @@ use Moose::Role;
 
 no warnings 'experimental';
 
-our $VERSION='0.02401';
+our $VERSION='0.10';
 
 =head1 NAME
 
 Vote::Count::Floor
 
-=head1 VERSION 0.02401
+=head1 VERSION 0.10
 
 =cut
 
 # ABSTRACT: Floor Rules for RCV elections.
 
 # load the roles providing the underlying ops.
-with  'Vote::Count::Approval',
-      'Vote::Count::TopCount',
-      ;
+with 'Vote::Count::Approval', 'Vote::Count::TopCount',;
 
-sub _FloorMin( $self, $floorpct ) {
+sub _FloorMin ( $self, $floorpct ) {
   my $pct = $floorpct >= 1 ? $floorpct / 100 : $floorpct;
   return int( $self->VotesCast() * $pct );
 }
 
-
-sub _DoFloor( $self, $ranked, $cutoff ) {
+sub _DoFloor ( $self, $ranked, $cutoff ) {
   my @active = ();
   my @remove = ();
   for my $s ( keys $ranked->%* ) {
-    if ( $ranked->{$s} >= $cutoff) { push @active, $s }
+    if ( $ranked->{$s} >= $cutoff ) { push @active, $s }
     else {
       push @remove, $s;
-      $self->logv(
-        "Removing: $s: $ranked->{$s}, minimum is $cutoff."
-      );
+      $self->logv("Removing: $s: $ranked->{$s}, minimum is $cutoff.");
     }
   }
   $self->logt(
     "Floor Rule Eliminated: ",
     join( ', ', @remove ),
-    "Remaining: ",
-    join( ', ', @active ),
-    );
+    "Remaining: ", join( ', ', @active ),
+  );
   return { map { $_ => 1 } @active };
 }
 
 # Approval Floor is Approval votes vs total
 # votes cast -- not total of approval votes.
 # so floor is the same as for topcount floor.
-sub ApprovalFloor( $self, $floorpct=5 ) {
+sub ApprovalFloor ( $self, $floorpct = 5 ) {
   my $votescast = $self->VotesCast();
-  $self->logt(
-    "Applying Floor Rule of $floorpct\% " .
-    "Approval Count. vs Ballots Cast of $votescast.");
-  return $self->_DoFloor(
-    $self->Approval()->RawCount(),
-    $self->_FloorMin($floorpct )
-  );
+  $self->logt( "Applying Floor Rule of $floorpct\% "
+      . "Approval Count. vs Ballots Cast of $votescast." );
+  return $self->_DoFloor( $self->Approval()->RawCount(),
+    $self->_FloorMin($floorpct) );
 }
 
-sub TopCountFloor( $self, $floorpct=2 ) {
-  $self->logt( "Applying Floor Rule of $floorpct\% First Choice Votes.");
-  return $self->_DoFloor(
-    $self->TopCount()->RawCount(),
-    $self->_FloorMin($floorpct )
-  );
+sub TopCountFloor ( $self, $floorpct = 2 ) {
+  $self->logt("Applying Floor Rule of $floorpct\% First Choice Votes.");
+  return $self->_DoFloor( $self->TopCount()->RawCount(),
+    $self->_FloorMin($floorpct) );
 }
 
 sub TCA( $self ) {
-  $self->logt( 'Applying Floor Rule: Approval Must be at least ',
-    '50% of the Most First Choice votes for any Choice.');
+  $self->logt(
+    'Applying Floor Rule: Approval Must be at least ',
+    '50% of the Most First Choice votes for any Choice.'
+  );
   my $tc = $self->TopCount();
   # arraytop returns a list in case of tie.
   my $winner = shift( $tc->ArrayTop->@* );
-  my $tcraw = $tc->RawCount()->{$winner};
-  my $cutoff = int( $tcraw /2 );
-  $self->logv(
-    "The most first choice votes for any choice is $tcraw.",
-    "Cutoff will be $cutoff");
+  my $tcraw  = $tc->RawCount()->{$winner};
+  my $cutoff = int( $tcraw / 2 );
+  $self->logv( "The most first choice votes for any choice is $tcraw.",
+    "Cutoff will be $cutoff" );
   my $ac = $self->Approval()->RawCount();
-  return $self->_DoFloor(
-    $self->Approval()->RawCount(),
-    $cutoff );
+  return $self->_DoFloor( $self->Approval()->RawCount(), $cutoff );
 }
 
 =head1 Floor Rules
@@ -133,7 +121,6 @@ For IRV any choice with an Approval that is not greater than the current TopCoun
 
 =cut
 
-
 1;
 
 #FOOTER
