@@ -21,7 +21,7 @@ use Try::Tiny;
 
 use Data::Printer;
 
-our $VERSION='0.02401';
+our $VERSION='0.10';
 
 # no warnings 'uninitialized';
 no warnings qw/experimental/;
@@ -30,7 +30,7 @@ no warnings qw/experimental/;
 
 Vote::Count::Method::CondorcetVsIRV
 
-=head1 VERSION 0.02401
+=head1 VERSION 0.10
 
 =cut
 
@@ -42,15 +42,27 @@ Vote::Count::Method::CondorcetVsIRV
 
   use Vote::Count::Method::CondorcetVsIRV;
 
-  ...
+  my $Election = Vote::Count::Method::CondorcetVsIRV->new( ... );
+  my $result = $Election->CondorcetVsIRV();
+  or
+  my $Election = Vote::Count->new( TieBreakMethod => 'approval' );
+  my $result = $Election->CondorcetVsIRV( relaxed => 1 );
+  equivalent to default:
+  my $result = $Election->CondorcetVsIRV( relaxed => 0, smithsetirv => 0 );
+
+  say $result->{'winner'};
+
+  $Election->WriteAllLogs();
+
+Returns a HashRef with a key for winner.
 
 =head1 Method Common Name: Condorcet vs IRV
 
 =head2 Method Summary
 
-Determine if the Condorcet Winner needed votes from the IRV winner, elect the Condorcet Winner if there was not a later harm violation, elect the IRV winner if there was. 
+Determine if the Condorcet Winner needed votes from the IRV winner, elect the Condorcet Winner if there was not a later harm violation, elect the IRV winner if there was.
 
-The Relaxed Later Harm option will select the Condorcet Winner when their margin of victory over the IRV Winner is greater than the number of later votes they need from the IRV Winner to be a Condorcet Winner. 
+The Relaxed Later Harm option will select the Condorcet Winner when their margin of victory over the IRV Winner is greater than the number of later votes they need from the IRV Winner to be a Condorcet Winner.
 
 This is a Redacting Condorcet Method because it uses Ballots which have been redacted for Later Harm effect.
 
@@ -66,11 +78,11 @@ It is optional to use Smith Set IRV for the case where there is no Condorcet Win
 
 =head2 Simplicity
 
-This is a medium complexity method. It builds on simpler methods but has a significant number of steps and branches. 
+This is a medium complexity method. It builds on simpler methods but has a significant number of steps and branches.
 
 =head2 Later Harm
 
-This method meets Later Harm with the default strict option. 
+This method meets Later Harm with the default strict option.
 
 The relaxed option allows a finite Later Harm effect.
 
@@ -78,42 +90,28 @@ Using the TCA Floor Rule and or Smith Set IRV add small Later Harm effects.
 
 =head2 Condorcet Criteria
 
-This method only meets Condorcet Loser, when the IRV winner is chosen of the Condorcet Winner, the winner is outside the Smith Set. 
+This method only meets Condorcet Loser, when the IRV winner is chosen of the Condorcet Winner, the winner is outside the Smith Set.
 Meets Condorcer Winner, Condorcet Loser, and Smith.
 
-=head32 Consistency
+=head2 Consistency
 
 Because this method chooses between the outcomes of two different methods, it inherits the consistency failings of both. It improves clone handling versus IRV, because in cases where the most supported clone loses IRV, it is often a Condorcet Winner. Likely there is overall improvement vs IRV.
 
 =head1 Implementation
 
-Details specific to this implementation. 
+Details specific to this implementation.
 
 The Tie Breaker is defaulted to (modified) Grand Junction for resolvability. Any Tie Breaker supported by Vote::Count::TieBreaker may be used, except that 'all' should not be used.
 
-There are two other important options: relaxed and smithsetirv. 
+There are two other important options: relaxed and smithsetirv.
 
 =head2 Function Name: CondorcetVsIRV
 
-CondorcetVsIRV is exported.
-
-  my $Election = Vote::Count->new( ... );
-  my $result = $Election->CondorcetVsIRV();
-  or
-  my $Election = Vote::Count->new( TieBreakMethod => 'approval' );
-  my $result = $Election->CondorcetVsIRV( relaxed => 1 );
-  equivalent to default:
-  my $result = $Election->CondorcetVsIRV( relaxed => 0, smithsetirv => 0 );
-
-  say $result->{'winner'};
-
-  $Election->WriteAllLogs();
-
-Returns a HashRef with a key for winner.
+Runs the election, returns a hashref containing the winner, similar to how other Vote::Count Methods such as RunIRV behave.
 
 =head2 LogTo, LogPath, LogBaseName, LogRedactedTo
 
-The first three behave as normal Vote::Count::Log methods, except that the default is /tmp/condorcetvsirv. 
+The first three behave as normal Vote::Count::Log methods, except that the default is /tmp/condorcetvsirv.
 
 LogRedactedTo defaults to appending _redacted into the log names for the  redacted election, it can be overridden by setting a value (which should be /path/basename) like LogTo.
 
@@ -125,207 +123,205 @@ WriteLog behaves normally, there is a log set for the CondorcetVSIRV object as w
 
 # LogTo over-writes role LogTo changing default filename.
 has 'LogTo' => (
-  is => 'rw',
-  isa => 'Str',
+  is      => 'rw',
+  isa     => 'Str',
   default => '/tmp/condorcetvsirv',
 );
 
-has 'LogRedactedTo' => ( 
-  is => 'lazy',
-  is => 'rw',
-  isa => 'Str',
+has 'LogRedactedTo' => (
+  is      => 'lazy',
+  is      => 'rw',
+  isa     => 'Str',
   builder => '_setredactedlog',
 );
 
-sub _setredactedlog ( $self ) { 
+sub _setredactedlog ( $self ) {
   # There is a bug with LogTo being uninitialized despite having a default
-  my $logto  = defined $self->LogTo()
+  my $logto =
+    defined $self->LogTo()
     ? $self->LogTo() . '_redacted'
-    : '/tmp/condorcetvsirv_redacted' ; 
-  return $logto ;
-};
+    : '/tmp/condorcetvsirv_redacted';
+  return $logto;
+}
 
 has 'TieBreakMethod' => (
-  is => 'ro',
-  isa => 'Str',
+  is      => 'ro',
+  isa     => 'Str',
   default => 'grandjunction',
 );
 
 has 'BallotSet' => ( is => 'ro', isa => 'HashRef', required => 1 );
 
-# has 'BallotSetType' => (
-#   is      => 'ro',
-#   isa     => 'Str',
-#   lazy    => 1,
-#   default =>  'rcv',
-# );
-
 has 'Active' => (
-  is => 'rw',
-  isa => 'HashRef',
-  lazy => 1,
-  builder => '_InitialActive', );
+  is      => 'rw',
+  isa     => 'HashRef',
+  lazy    => 1,
+  builder => '_InitialActive',
+);
 
 sub _InitialActive ( $I ) { return dclone $I->BallotSet()->{'choices'} }
 
 sub SetActive ( $I, $active ) {
   $I->{'Active'} = dclone $active;
-  $I->{'Election'}->SetActive( $active );
+  $I->{'Election'}->SetActive($active);
   if ( defined $I->{'RedactedElection'} ) {
-    $I->{'RedactedElection'}->SetActive( $active );
+    $I->{'RedactedElection'}->SetActive($active);
   }
 }
 
-sub ResetActive ( $self ) { 
+sub ResetActive ( $self ) {
   my $new = dclone $self->BallotSet()->{'choices'};
-  $self->SetActive( $new );
+  $self->SetActive($new);
   return $new;
 }
 
 # sub ResetActive ( $self ) { return dclone $self->BallotSet()->{'choices'} }
 
-sub _CVI_IRV ( $I, $active, $smithsetirv ) {  
-  my $WonIRV = undef;
+sub _CVI_IRV ( $I, $active, $smithsetirv ) {
+  my $WonIRV    = undef;
   my $irvresult = undef;
   if ($smithsetirv) {
-# smithirv needs to match irv args.
-    $irvresult = $I->SmithSetIRV( $I->TieBreakMethod() );  
-  } else {  
+    # smithirv needs to match irv args.
+    $irvresult = $I->SmithSetIRV( $I->TieBreakMethod() );
+  }
+  else {
     $irvresult = $I->RunIRV( $active, $I->TieBreakMethod() );
   }
   return $irvresult->{'winner'} if $irvresult->{'winner'};
-  $I->logt( "Aborting Election. IRV ended with a Tie.");
-  $I->logt( "Active (Tied) Choices are: " . join( ', ', $irvresult->{'tied'}));
-  $I->SetActiveFromArrayRef( $irvresult->{'tied'});
+  $I->logt("Aborting Election. IRV ended with a Tie.");
+  $I->logt(
+    "Active (Tied) Choices are: " . join( ', ', $irvresult->{'tied'} ) );
+  $I->SetActiveFromArrayRef( $irvresult->{'tied'} );
   return 0;
 }
 
 sub BUILD {
-    my $self = shift;
-    $self->{'Election'} = Vote::Count::Method::CondorcetIRV->new(
-        BallotSet      => $self->BallotSet(),
-        TieBreakMethod => $self->TieBreakMethod(),
-        Active         => $self->Active(),
-        BallotSetType  => 'rcv',
-        LogTo          => $self->{'LogTo'} . '_unredacted' ,
-    );
-    $self->{'RedactedElection'} = undef,;
+  my $self = shift;
+  $self->{'Election'} = Vote::Count::Method::CondorcetIRV->new(
+    BallotSet      => $self->BallotSet(),
+    TieBreakMethod => $self->TieBreakMethod(),
+    Active         => $self->Active(),
+    BallotSetType  => 'rcv',
+    LogTo          => $self->{'LogTo'} . '_unredacted',
+  );
+  $self->{'RedactedElection'} = undef,;
 }
 
 sub WriteAllLogs ($I) {
   $I->WriteLog();
   $I->Election()->WriteLog();
-  $I->RedactedElection()->WriteLog();  
+  $I->RedactedElection()->WriteLog();
   $I->Election()->PairMatrix()->WriteLog();
-  $I->RedactedElection()->PairMatrix()->WriteLog();    
+  $I->RedactedElection()->PairMatrix()->WriteLog();
 }
 
 sub Election ($self) { return $self->{'Election'} }
 
-sub RedactedElection ( $self, $ballotset=undef, $active=undef ) { 
-  return $self->{'RedactedElection'} }
+sub RedactedElection ( $self, $ballotset = undef, $active = undef ) {
+  return $self->{'RedactedElection'};
+}
 
 sub CreateRedactedElection ( $self, $WonCondorcet, $WonIRV ) {
-  my $ballotset = 
-    RedactPair( $self->BallotSet(), $WonCondorcet, $WonIRV );
-  $self->{'RedactedElection'} =
-  Vote::Count::Method::CondorcetIRV->new(
-    BallotSet => $ballotset,
+  my $ballotset = RedactPair( $self->BallotSet(), $WonCondorcet, $WonIRV );
+  $self->{'RedactedElection'} = Vote::Count::Method::CondorcetIRV->new(
+    BallotSet      => $ballotset,
     TieBreakMethod => $self->TieBreakMethod(),
-    Active => $self->Active(),
-    BallotSetType => 'rcv',
-    LogTo => $self->LogRedactedTo(),
-    ); 
+    Active         => $self->Active(),
+    BallotSetType  => 'rcv',
+    LogTo          => $self->LogRedactedTo(),
+  );
 }
 
 #  $I, $active, $smithsetirv
 sub _CVI_RedactRun ( $I, $WonCondorcet, $WonIRV, $active, $options ) {
-  my $smithsetirv = defined $options->{'smithsetirv'} ?$options->{'smithsetirv'} :0;
-  my $relaxed = defined $options->{'relaxed'} ? $options->{'relaxed'} : 0 ;
-  my $E = $I->Election();
-  my $R = $I->RedactedElection();
+  my $smithsetirv =
+    defined $options->{'smithsetirv'} ? $options->{'smithsetirv'} : 0;
+  my $relaxed  = defined $options->{'relaxed'} ? $options->{'relaxed'} : 0;
+  my $E        = $I->Election();
+  my $R        = $I->RedactedElection();
   my $ConfirmC = $R->PairMatrix->CondorcetWinner();
   my $ConfirmI = _CVI_IRV( $R, $active, $smithsetirv );
-  if ( $ConfirmC eq $WonCondorcet or $ConfirmC eq $WonIRV) { 
-    $I->logt( "Elected $ConfirmC, Redacted Ballots Condorcet Winner.");
+  if ( $ConfirmC eq $WonCondorcet or $ConfirmC eq $WonIRV ) {
+    $I->logt("Elected $ConfirmC, Redacted Ballots Condorcet Winner.");
     return $ConfirmC;
   }
   else {
     $ConfirmI = _CVI_IRV( $R, $active, $smithsetirv );
-    if ( $ConfirmI eq $WonCondorcet or $ConfirmI eq $WonIRV) { 
-      $I->logt( "Elected $ConfirmI, Redacted Ballots IRV Winner.");
+    if ( $ConfirmI eq $WonCondorcet or $ConfirmI eq $WonIRV ) {
+      $I->logt("Elected $ConfirmI, Redacted Ballots IRV Winner.");
       return $ConfirmI;
     }
   }
   $ConfirmC = 'NONE' unless $ConfirmC;
-  $I->logt( "Neither $WonCondorcet nor $WonIRV were confirmed.");
-  $I->logt( "Redacted Ballots Winners: Condorcet = $ConfirmC, IRV = $ConfirmI");
-  if( $relaxed ) {
-    my $GreatestLoss = $R->PairMatrix()->GreatestLoss( $WonCondorcet );
-    my $Margin = $E->PairMatrix()->GetPairResult( $WonCondorcet, $WonIRV )->{'margin'};
-    $I->logt( "The margin of the Condorcet over the IRV winner was: $Margin");
-    $I->logt( "$WonCondorcet\'s greatest loss with redacted ballots was $GreatestLoss.");    
+  $I->logt("Neither $WonCondorcet nor $WonIRV were confirmed.");
+  $I->logt(
+    "Redacted Ballots Winners: Condorcet = $ConfirmC, IRV = $ConfirmI");
+  if ($relaxed) {
+    my $GreatestLoss = $R->PairMatrix()->GreatestLoss($WonCondorcet);
+    my $Margin =
+      $E->PairMatrix()->GetPairResult( $WonCondorcet, $WonIRV )->{'margin'};
+    $I->logt("The margin of the Condorcet over the IRV winner was: $Margin");
+    $I->logt(
+"$WonCondorcet\'s greatest loss with redacted ballots was $GreatestLoss."
+    );
     if ( $Margin > $GreatestLoss ) {
-      $I->logt( "Elected: $WonCondorcet" );
+      $I->logt("Elected: $WonCondorcet");
       return $WonCondorcet;
-    } 
+    }
   }
-  $I->logt( "Elected: $WonIRV" );
+  $I->logt("Elected: $WonIRV");
   return $WonIRV;
 }
 
 sub CondorcetVsIRV ( $self, %args ) {
-  my $E = $self->Election();
-  my $smithsetirv = defined $args{'smithsetirv'} ? $args{'smithsetirv'} : 0 ;
-  my $active = $self->Active();
+  my $E           = $self->Election();
+  my $smithsetirv = defined $args{'smithsetirv'} ? $args{'smithsetirv'} : 0;
+  my $active      = $self->Active();
   # check for majority winner.
   my $majority = $E->EvaluateTopCountMajority()->{'winner'};
-  return $majority if $majority ;
-  my $WonIRV = undef;
+  return $majority if $majority;
+  my $WonIRV       = undef;
   my $WonCondorcet = $E->PairMatrix()->CondorcetWinner();
   if ($WonCondorcet) {
-    $self->logt( "Condorcet Winner is $WonCondorcet");
+    $self->logt("Condorcet Winner is $WonCondorcet");
     # Even if SmithSetIRV requested, it would return the condorcet winner
     # We need to know if a different choice would win IRV.
     $WonIRV = $E->RunIRV( $active, $E->TieBreakMethod() )->{'winner'};
-  } else {
-    $self->logt( "No Condorcet Winner" );
+  }
+  else {
+    $self->logt("No Condorcet Winner");
     $WonIRV = _CVI_IRV( $E, $active, $smithsetirv );
-    $self->logt( "Electing IRV Winner $WonIRV");
+    $self->logt("Electing IRV Winner $WonIRV");
     return { 'winner' => $WonIRV };
   }
 
   # IRV private already logged tie, now return the false value.
   # Edge case IRV tie with Condorcet Winner, I guess CW wins?
-  unless ( $WonIRV ) {
-    if ($WonCondorcet) { 
-      $self->logt( "Electing Condorcet Winner $WonCondorcet, IRV tied.");
-      return $WonCondorcet ;
+  unless ($WonIRV) {
+    if ($WonCondorcet) {
+      $self->logt("Electing Condorcet Winner $WonCondorcet, IRV tied.");
+      return $WonCondorcet;
     }
-    return { 'winner' => 0 }; 
+    return { 'winner' => 0 };
   }
-  if ( $WonIRV eq $WonCondorcet ) { 
-    $self->logt( "Electing $WonIRV the winner by both Condorcet and IRV.");
+  if ( $WonIRV eq $WonCondorcet ) {
+    $self->logt("Electing $WonIRV the winner by both Condorcet and IRV.");
     return { 'winner' => $WonIRV };
   }
-  if ( $WonIRV and !$WonCondorcet ) { 
-    $self->logt( "Electing IRV Winner $WonIRV. There was no Condorcet Winner.");
+  if ( $WonIRV and !$WonCondorcet ) {
+    $self->logt(
+      "Electing IRV Winner $WonIRV. There was no Condorcet Winner.");
     return { 'winner' => $WonIRV };
   }
-  $self->CreateRedactedElection( $WonCondorcet, $WonIRV);
-  my $winner = $self->_CVI_RedactRun( $WonCondorcet, $WonIRV, $active, \%args );
+  $self->CreateRedactedElection( $WonCondorcet, $WonIRV );
+  my $winner =
+    $self->_CVI_RedactRun( $WonCondorcet, $WonIRV, $active, \%args );
   return { 'winner' => $winner };
 
-
-# sub _CVI_RedactRun ( $I, $WonCondorcet, $WonIRV, $active, %args ) {
-
-  # return $WonIRV;
 }
 
 1;
 
-
-
 #FOOTER
 
 =pod
